/**
 * Copyright (c) 2011, Leena Salmela <leena.salmela@cs.helsinki.fi>
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHORS ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
#include <set>
#include <map>
#include <iostream>
#include <fstream>

#include <stdlib.h>
#include <stdio.h>
#include <dirent.h>
#include <string.h>
#include <limits.h>

using namespace std;

#include "io.h"
#include "align.h"

typedef struct {
  int contig;
  int start;
  int end;
} contig_t;

int compare_contig(const void *p1, const void *p2) {
  contig_t *c1 = (contig_t *) p1;
  contig_t *c2 = (contig_t *) p2;

  int pos1, pos2;

  pos1 = (c1->start < c1->end) ? c1->start : c1->end;
  pos2 = (c2->start < c2->end) ? c2->start : c2->end;

  return pos1-pos2;
}

int compare_int(const void *p1, const void *p2) {
  int i1 = *((int *)p1);
  int i2 = *((int *)p1);

  return i1-i2;
}

int main(int argc, char *argv[]) {
  int *contig_length;
  char **contig_seq;
  char **contig_names;
  map<string,int> contig2id;

  read_contigs(argv[1], &contig_length, &contig_seq, &contig_names, &contig2id);

  printf("Read contigs\n");

  translate_scaffolds(argv[2], argv[3], argv[4], contig_length, contig_seq, 
                      contig_names, &contig2id);

  return 0;
}
